==> blesta-5.10.2.zip: blesta/plugins/order/language/da_dk/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'Den indtastede captcha var ugyldig. Prøv venligst igen.';
$lang['Signup.!error.not_client_owner'] = 'Du skal være logget ind som klientens ejer for at kunne fortsætte.';
$lang['Signup.!notice.force_email_usernames'] = 'Dit brugernavn vil være det samme som din e-mailadresse.';
$lang['Signup.!notice.email_verification'] = 'Der er blevet sendt en besked for at bekræfte din e-mailadresse. Fuldfør venligst bekræftelsen så hurtigt som muligt.';
$lang['Signup.index.field_taxid'] = 'Skatte-ID/VATIN';
$lang['Signup.index.field_firstname'] = 'Fornavn';
$lang['Signup.index.field_lastname'] = 'Efternavn';
$lang['Signup.index.field_company'] = 'Virksomhed/Org.';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_city'] = 'By';
$lang['Signup.index.field_state'] = 'Stat/provins';
$lang['Signup.index.field_zip'] = 'Postnummer';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'E-mail';
$lang['Signup.index.field_username_type_email'] = 'Brug e-mail som brugernavn';
$lang['Signup.index.field_username_type_username'] = 'Angiv et brugernavn';
$lang['Signup.index.field_action_continue'] = 'Fortsæt som %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Log ind';
$lang['Signup.index.field_action_signup'] = 'Opret en konto';
$lang['Signup.index.field_username'] = 'Brugernavn';
$lang['Signup.index.field_password'] = 'Adgangskode';
$lang['Signup.index.field_newpassword'] = 'Adgangskode';
$lang['Signup.index.field_confirmpassword'] = 'Bekræft adgangskode';
$lang['Signup.index.field_receive_email_marketing'] = 'Jeg vil gerne modtage e-mails om nye produkter, tjenester og tilbud.';
$lang['Signup.index.login_btn'] = 'Log ind';
$lang['Signup.index.continue_btn'] = 'Fortsæt til kassen';
$lang['Signup.index.signup_btn'] = 'Opret konto';
$lang['Signup.!error.email.blacklist'] = 'Din ordre kan ikke behandles på nuværende tidspunkt.';
$lang['Signup.index.field_recovery_email'] = 'E-mail til gendannelse (valgfri)';

==> blesta-5.11.4.zip: blesta/plugins/order/language/da_dk/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'Den indtastede captcha var ugyldig. Prøv venligst igen.';
$lang['Signup.!error.not_client_owner'] = 'Du skal være logget ind som klientens ejer for at kunne fortsætte.';
$lang['Signup.!notice.force_email_usernames'] = 'Dit brugernavn vil være det samme som din e-mailadresse.';
$lang['Signup.!notice.email_verification'] = 'Der er blevet sendt en besked for at bekræfte din e-mailadresse. Fuldfør venligst bekræftelsen så hurtigt som muligt.';
$lang['Signup.index.field_taxid'] = 'Skatte-ID/VATIN';
$lang['Signup.index.field_firstname'] = 'Fornavn';
$lang['Signup.index.field_lastname'] = 'Efternavn';
$lang['Signup.index.field_company'] = 'Virksomhed/Org.';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_city'] = 'By';
$lang['Signup.index.field_state'] = 'Stat/provins';
$lang['Signup.index.field_zip'] = 'Postnummer';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'E-mail';
$lang['Signup.index.field_username_type_email'] = 'Brug e-mail som brugernavn';
$lang['Signup.index.field_username_type_username'] = 'Angiv et brugernavn';
$lang['Signup.index.field_action_continue'] = 'Fortsæt som %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Log ind';
$lang['Signup.index.field_action_signup'] = 'Opret en konto';
$lang['Signup.index.field_username'] = 'Brugernavn';
$lang['Signup.index.field_password'] = 'Adgangskode';
$lang['Signup.index.field_newpassword'] = 'Adgangskode';
$lang['Signup.index.field_confirmpassword'] = 'Bekræft adgangskode';
$lang['Signup.index.field_receive_email_marketing'] = 'Jeg vil gerne modtage e-mails om nye produkter, tjenester og tilbud.';
$lang['Signup.index.login_btn'] = 'Log ind';
$lang['Signup.index.continue_btn'] = 'Fortsæt til kassen';
$lang['Signup.index.signup_btn'] = 'Opret konto';
$lang['Signup.!error.email.blacklist'] = 'Din ordre kan ikke behandles på nuværende tidspunkt.';
$lang['Signup.index.field_recovery_email'] = 'E-mail til gendannelse (valgfri)';
$lang['Signup.otp.field_submit'] = 'Log ind';
$lang['Signup.otp.field_otp'] = 'Engangsadgangskode';
$lang['Signup.otp.login_heading'] = 'Log ind';
$lang['Signup.otp.description'] = 'Indtast venligst din engangsadgangskode.';
$lang['Signup.otp.page_title'] = 'Log ind';
$lang['Signup.index.field_agree_tos'] = 'Jeg har læst og accepterer <a href="%1$s" target="_blank">vilkår og betingelser.</a>';
$lang['Signup.!error.invalid_agree_tos'] = 'Du skal bekræfte, at du er indforstået med vilkårene og betingelserne.';
